/* GomElementTest.c generated by valac 0.34.6, the Vala compiler
 * generated from GomElementTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* Notation.vala
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <gxml/gxml.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>


#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_GOM_ELEMENT_TEST (gom_element_test_get_type ())
#define GOM_ELEMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_ELEMENT_TEST, GomElementTest))
#define GOM_ELEMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_ELEMENT_TEST, GomElementTestClass))
#define IS_GOM_ELEMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_ELEMENT_TEST))
#define IS_GOM_ELEMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_ELEMENT_TEST))
#define GOM_ELEMENT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_ELEMENT_TEST, GomElementTestClass))

typedef struct _GomElementTest GomElementTest;
typedef struct _GomElementTestClass GomElementTestClass;
typedef struct _GomElementTestPrivate GomElementTestPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _GomElementTest {
	GXmlTest parent_instance;
	GomElementTestPrivate * priv;
};

struct _GomElementTestClass {
	GXmlTestClass parent_class;
};


static gpointer gom_element_test_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_gxml_test (GValue* value, gpointer v_object);
void value_take_gxml_test (GValue* value, gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType gom_element_test_get_type (void) G_GNUC_CONST;
enum  {
	GOM_ELEMENT_TEST_DUMMY_PROPERTY
};
void gom_element_test_add_tests (void);
static void __lambda235_ (void);
static void ___lambda235__gtest_func (void);
static void __lambda236_ (void);
static void ___lambda236__gtest_func (void);
static void __lambda237_ (void);
static void ___lambda237__gtest_func (void);
static void __lambda238_ (void);
static void ___lambda238__gtest_func (void);
static void __lambda239_ (void);
static void ___lambda239__gtest_func (void);
static void __lambda240_ (void);
static void ___lambda240__gtest_func (void);
GomElementTest* gom_element_test_new (void);
GomElementTest* gom_element_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


static void __lambda235_ (void) {
	GXmlDomDocument* doc = NULL;
	GError * _inner_error_ = NULL;
#line 28 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	doc = NULL;
#line 125 "GomElementTest.c"
	{
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_ = NULL;
		GXmlGomNode* root = NULL;
		GXmlDomDocument* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlDomElement* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		GXmlGomNode* node = NULL;
		GXmlDomNodeList* _tmp9_ = NULL;
		GXmlDomNodeList* _tmp10_ = NULL;
		GXmlDomNodeList* _tmp11_ = NULL;
		gpointer _tmp12_ = NULL;
		GXmlGomNode* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		GXmlDomNamedNodeMap* _tmp26_ = NULL;
		GXmlDomNamedNodeMap* _tmp27_ = NULL;
		GXmlDomNamedNodeMap* _tmp28_ = NULL;
		gint _tmp29_ = 0;
		gint _tmp30_ = 0;
		GXmlDomNamedNodeMap* _tmp31_ = NULL;
		GXmlDomNamedNodeMap* _tmp32_ = NULL;
		GXmlDomNamedNodeMap* _tmp33_ = NULL;
		gint _tmp34_ = 0;
		gint _tmp35_ = 0;
		gchar* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		gchar* _tmp40_ = NULL;
		gchar* _tmp41_ = NULL;
		gchar* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		gchar* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
		gchar* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
#line 30 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gxml_gom_document_new_from_string ("<Potions><magic:Potion xmlns:magic=\"http://hogwarts.co.uk/magic\" xml" \
"ns:products=\"http://diagonalley.co.uk/products\"/></Potions>", &_inner_error_);
#line 30 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = _tmp1_;
#line 30 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 187 "GomElementTest.c"
			goto __catch225_g_error;
		}
#line 30 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = _tmp0_;
#line 30 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = NULL;
#line 30 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 30 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = (GXmlDomDocument*) _tmp2_;
#line 31 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = doc;
#line 31 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element (_tmp3_);
#line 31 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 31 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GXML_TYPE_GOM_NODE, GXmlGomNode);
#line 32 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (root != NULL, "root != null");
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = gxml_dom_node_get_node_name ((GXmlDomNode*) root);
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp8_, "Potions") == 0, "root.node_name == \"Potions\"");
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp8_);
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) root);
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = gee_list_get ((GeeList*) _tmp11_, 0);
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomNode*) _tmp12_, GXML_TYPE_GOM_NODE, GXmlGomNode);
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp11_);
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		node = _tmp13_;
#line 35 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (node != NULL, "node != null");
#line 36 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT), "node is DomElement");
#line 37 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = gxml_dom_element_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) node) : NULL);
#line 37 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = _tmp14_;
#line 37 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = _tmp15_;
#line 37 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp16_, "Potion") == 0, "(node as DomElement).local_name == \"Potion\"");
#line 37 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp16_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = gxml_dom_node_get_node_name ((GXmlDomNode*) node);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = _tmp17_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = _tmp18_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp19_, "magic:Potion") == 0, "node.node_name == \"magic:Potion\"");
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp19_);
#line 39 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = gxml_dom_element_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) node) : NULL);
#line 39 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = _tmp20_;
#line 39 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 39 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp22_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).namespace_uri == \"http://hogwarts.co.uk/magic\"");
#line 39 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp22_);
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = gxml_dom_element_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) node) : NULL);
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = _tmp23_;
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp25_, "magic") == 0, "(node as DomElement).prefix == \"magic\"");
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp25_);
#line 41 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = gxml_dom_element_get_attributes (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) node) : NULL);
#line 41 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = _tmp26_;
#line 41 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = _tmp27_;
#line 41 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = gee_map_get_size ((GeeMap*) _tmp28_);
#line 41 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = _tmp29_;
#line 41 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp30_ == 2, "(node as DomElement).attributes.size == 2");
#line 41 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp28_);
#line 42 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = gxml_dom_element_get_attributes (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) node) : NULL);
#line 42 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = _tmp31_;
#line 42 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 42 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = gee_map_get_size ((GeeMap*) _tmp33_);
#line 42 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = _tmp34_;
#line 42 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = g_strdup_printf ("%i", _tmp35_);
#line 42 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 42 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = g_strconcat ("Attributes: ", _tmp37_, NULL);
#line 42 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 42 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:42: %s", _tmp39_);
#line 42 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp39_);
#line 42 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp37_);
#line 42 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp33_);
#line 48 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = gxml_dom_element_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) node) : NULL, "xmlns:magic");
#line 48 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = _tmp40_;
#line 48 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp41_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).get_attribute (\"xmlns:magic\") == \"http://hogwarts.co.uk/magic\"");
#line 48 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp41_);
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) node) : NULL, "http://www.w3.org/2000/xmlns/", "magic");
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = _tmp42_;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp43_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).get_attribute_ns (\"http://www.w3.org/2000/xmlns/\", \"magic\") == \"http://hogwarts.co.uk/magic\"");
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp43_);
#line 50 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = gxml_dom_element_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) node) : NULL, "xmlns:products");
#line 50 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 50 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp45_, "http://diagonalley.co.uk/products") == 0, "(node as DomElement).get_attribute (\"xmlns:products\") == \"http://diagonalley.co.uk/products\"");
#line 50 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp45_);
#line 51 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) node) : NULL, "http://www.w3.org/2000/xmlns/", "products");
#line 51 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 51 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp47_, "http://diagonalley.co.uk/products") == 0, "(node as DomElement).get_attribute_ns (\"http://www.w3.org/2000/xmlns/\",\"products\") == \"http://diagonalley.co.uk/products\"");
#line 51 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp47_);
#line 52 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) node, "http://diagonalley.co.uk/products");
#line 52 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = _tmp48_;
#line 52 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp49_, "products") == 0, "node.lookup_prefix (\"http://diagonalley.co.uk/products\") == \"products\"");
#line 52 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp49_);
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) node, "products");
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = _tmp50_;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp51_, "http://diagonalley.co.uk/products") == 0, "node.lookup_namespace_uri (\"products\") == \"http://diagonalley.co.uk/products\"");
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp51_);
#line 29 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (node);
#line 29 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (root);
#line 29 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp0_);
#line 370 "GomElementTest.c"
	}
	goto __finally225;
	__catch225_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp52_ = NULL;
#line 29 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 29 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 55 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp52_ = e->message;
#line 55 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:55: %s", _tmp52_);
#line 56 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 29 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 389 "GomElementTest.c"
	}
	__finally225:
#line 29 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 29 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 29 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 29 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 29 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 402 "GomElementTest.c"
	}
#line 27 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (doc);
#line 406 "GomElementTest.c"
}


static void ___lambda235__gtest_func (void) {
#line 27 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda235_ ();
#line 413 "GomElementTest.c"
}


static void __lambda236_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomNode* root = NULL;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		GXmlGomNode* node = NULL;
		GXmlDomNodeList* _tmp6_ = NULL;
		GXmlDomNodeList* _tmp7_ = NULL;
		GXmlDomNodeList* _tmp8_ = NULL;
		gpointer _tmp9_ = NULL;
		GXmlGomNode* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		GXmlDomNamedNodeMap* _tmp23_ = NULL;
		GXmlDomNamedNodeMap* _tmp24_ = NULL;
		GXmlDomNamedNodeMap* _tmp25_ = NULL;
		gint _tmp26_ = 0;
		gint _tmp27_ = 0;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
#line 61 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<Potions><magic:Potion xmlns:magic=\"http://hogwarts.co.uk/magic\" xml" \
"ns:products=\"http://diagonalley.co.uk/products\"/></Potions>", &_inner_error_);
#line 61 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 61 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 469 "GomElementTest.c"
			goto __catch226_g_error;
		}
#line 62 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 62 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = _tmp1_;
#line 62 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GXML_TYPE_GOM_NODE, GXmlGomNode);
#line 63 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (root != NULL, "root != null");
#line 64 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = gxml_dom_node_get_node_name ((GXmlDomNode*) root);
#line 64 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = _tmp3_;
#line 64 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 64 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp5_, "Potions") == 0, "root.node_name == \"Potions\"");
#line 64 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp5_);
#line 65 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) root);
#line 65 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 65 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 65 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = gee_list_get ((GeeList*) _tmp8_, 0);
#line 65 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomNode*) _tmp9_, GXML_TYPE_GOM_NODE, GXmlGomNode);
#line 65 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 65 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		node = _tmp10_;
#line 66 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (node != NULL, "node != null");
#line 67 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT), "node is DomElement");
#line 68 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = gxml_dom_element_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) node) : NULL);
#line 68 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 68 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = _tmp12_;
#line 68 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp13_, "Potion") == 0, "(node as DomElement).local_name == \"Potion\"");
#line 68 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp13_);
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = gxml_dom_node_get_node_name ((GXmlDomNode*) node);
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = _tmp14_;
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = _tmp15_;
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp16_, "magic:Potion") == 0, "node.node_name == \"magic:Potion\"");
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp16_);
#line 70 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = gxml_dom_element_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) node) : NULL);
#line 70 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = _tmp17_;
#line 70 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = _tmp18_;
#line 70 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp19_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).namespace_uri == \"http://hogwarts.co.uk/magic\"");
#line 70 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp19_);
#line 71 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = gxml_dom_element_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) node) : NULL);
#line 71 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = _tmp20_;
#line 71 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 71 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp22_, "magic") == 0, "(node as DomElement).prefix == \"magic\"");
#line 71 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp22_);
#line 81 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = gxml_dom_element_get_attributes (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) node) : NULL);
#line 81 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = _tmp23_;
#line 81 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 81 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = gxml_dom_named_node_map_get_length (_tmp25_);
#line 81 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = _tmp26_;
#line 81 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp27_ == 2, "(node as DomElement).attributes.length == 2");
#line 81 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp25_);
#line 82 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = gxml_dom_element_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) node) : NULL, "xmlns:magic");
#line 82 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = _tmp28_;
#line 82 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp29_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).get_attribute (\"xmlns:magic\") == \"http://hogwarts.co.uk/magic\"");
#line 82 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp29_);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) node) : NULL, "http://www.w3.org/2000/xmlns/", "magic");
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = _tmp30_;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp31_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).get_attribute_ns (\"http://www.w3.org/2000/xmlns/\", \"magic\") == \"http://hogwarts.co.uk/magic\"");
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp31_);
#line 84 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = gxml_dom_element_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) node) : NULL, "xmlns:products");
#line 84 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 84 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp33_, "http://diagonalley.co.uk/products") == 0, "(node as DomElement).get_attribute (\"xmlns:products\") == \"http://diagonalley.co.uk/products\"");
#line 84 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp33_);
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) node) : NULL, "http://www.w3.org/2000/xmlns/", "products");
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = _tmp34_;
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp35_, "http://diagonalley.co.uk/products") == 0, "(node as DomElement).get_attribute_ns (\"http://www.w3.org/2000/xmlns/\",\"products\") == \"http://diagonalley.co.uk/products\"");
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp35_);
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) node, "http://diagonalley.co.uk/products");
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp37_, "products") == 0, "node.lookup_prefix (\"http://diagonalley.co.uk/products\") == \"products\"");
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp37_);
#line 87 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) node, "products");
#line 87 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 87 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp39_, "http://diagonalley.co.uk/products") == 0, "node.lookup_namespace_uri (\"products\") == \"http://diagonalley.co.uk/products\"");
#line 87 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp39_);
#line 60 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (node);
#line 60 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (root);
#line 60 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 616 "GomElementTest.c"
	}
	goto __finally226;
	__catch226_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp40_ = NULL;
#line 60 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 60 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 89 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = e->message;
#line 89 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:89: %s", _tmp40_);
#line 90 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 60 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 635 "GomElementTest.c"
	}
	__finally226:
#line 60 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 60 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 60 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 60 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 646 "GomElementTest.c"
	}
}


static void ___lambda236__gtest_func (void) {
#line 59 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda236_ ();
#line 654 "GomElementTest.c"
}


static void __lambda237_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlDomElement* _tmp5_ = NULL;
		GXmlGomDocument* _tmp6_ = NULL;
		GXmlDomElement* _tmp7_ = NULL;
		GXmlGomElement* elem = NULL;
		GXmlDomElement* _tmp8_ = NULL;
		GXmlGomDocument* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlDomElement* _tmp11_ = NULL;
		GXmlDomElement* _tmp12_ = NULL;
		GXmlDomNodeList* _tmp13_ = NULL;
		GXmlDomNodeList* _tmp14_ = NULL;
		GXmlDomNodeList* _tmp15_ = NULL;
		GXmlGomElement* _tmp16_ = NULL;
		GXmlGomElement* _tmp17_ = NULL;
		GXmlDomNamedNodeMap* _tmp18_ = NULL;
		GXmlDomNamedNodeMap* _tmp19_ = NULL;
		GXmlDomNamedNodeMap* _tmp20_ = NULL;
		GXmlGomElement* _tmp21_ = NULL;
		GXmlDomNamedNodeMap* _tmp22_ = NULL;
		GXmlDomNamedNodeMap* _tmp23_ = NULL;
		GXmlDomNamedNodeMap* _tmp24_ = NULL;
		gint _tmp25_ = 0;
		gint _tmp26_ = 0;
		GXmlGomElement* _tmp27_ = NULL;
		GXmlGomElement* _tmp28_ = NULL;
		GXmlGomElement* _tmp29_ = NULL;
		GXmlDomNamedNodeMap* _tmp30_ = NULL;
		GXmlDomNamedNodeMap* _tmp31_ = NULL;
		GXmlDomNamedNodeMap* _tmp32_ = NULL;
		gint _tmp33_ = 0;
		gint _tmp34_ = 0;
		GXmlXParser* parser = NULL;
		GXmlGomDocument* _tmp35_ = NULL;
		GXmlXParser* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
		GXmlXParser* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		gchar* _tmp40_ = NULL;
		gchar* _tmp41_ = NULL;
		gchar* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		GXmlGomElement* _tmp44_ = NULL;
		GXmlDomNamedNodeMap* _tmp45_ = NULL;
		GXmlDomNamedNodeMap* _tmp46_ = NULL;
		GXmlDomNamedNodeMap* _tmp47_ = NULL;
		GXmlDomNode* _tmp48_ = NULL;
		GXmlDomNode* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
		GXmlGomElement* _tmp53_ = NULL;
		GXmlDomNamedNodeMap* _tmp54_ = NULL;
		GXmlDomNamedNodeMap* _tmp55_ = NULL;
		GXmlDomNamedNodeMap* _tmp56_ = NULL;
		GXmlDomNode* _tmp57_ = NULL;
		GXmlDomNode* _tmp58_ = NULL;
		gchar* _tmp59_ = NULL;
		gchar* _tmp60_ = NULL;
		gchar* _tmp61_ = NULL;
		GXmlGomElement* _tmp62_ = NULL;
		GXmlGomAttr* attr = NULL;
		GXmlGomElement* _tmp63_ = NULL;
		GXmlDomNamedNodeMap* _tmp64_ = NULL;
		GXmlDomNamedNodeMap* _tmp65_ = NULL;
		GXmlDomNamedNodeMap* _tmp66_ = NULL;
		GXmlDomNode* _tmp67_ = NULL;
		GXmlGomAttr* _tmp68_ = NULL;
		GXmlGomAttr* _tmp69_ = NULL;
		GXmlGomAttr* _tmp70_ = NULL;
		GXmlGomAttr* _tmp71_ = NULL;
		gchar* _tmp72_ = NULL;
		gchar* _tmp73_ = NULL;
		gchar* _tmp74_ = NULL;
		GXmlGomElement* _tmp75_ = NULL;
		GXmlDomNamedNodeMap* _tmp76_ = NULL;
		GXmlDomNamedNodeMap* _tmp77_ = NULL;
		GXmlDomNamedNodeMap* _tmp78_ = NULL;
		gint _tmp79_ = 0;
		gint _tmp80_ = 0;
		GXmlGomElement* _tmp81_ = NULL;
		gchar* _tmp82_ = NULL;
		gchar* _tmp83_ = NULL;
		GXmlGomElement* _tmp84_ = NULL;
		GXmlDomNamedNodeMap* _tmp85_ = NULL;
		GXmlDomNamedNodeMap* _tmp86_ = NULL;
		GXmlDomNamedNodeMap* _tmp87_ = NULL;
		GXmlDomNode* _tmp88_ = NULL;
		GXmlDomNode* _tmp89_ = NULL;
		GXmlGomElement* _tmp90_ = NULL;
		gchar* _tmp91_ = NULL;
		gchar* _tmp92_ = NULL;
		GXmlGomElement* _tmp93_ = NULL;
		GXmlDomNamedNodeMap* _tmp94_ = NULL;
		GXmlDomNamedNodeMap* _tmp95_ = NULL;
		GXmlDomNamedNodeMap* _tmp96_ = NULL;
		gint _tmp97_ = 0;
		gint _tmp98_ = 0;
		GXmlGomElement* _tmp99_ = NULL;
		GXmlGomElement* _tmp100_ = NULL;
		GXmlDomNamedNodeMap* _tmp101_ = NULL;
		GXmlDomNamedNodeMap* _tmp102_ = NULL;
		GXmlDomNamedNodeMap* _tmp103_ = NULL;
		gint _tmp104_ = 0;
		gint _tmp105_ = 0;
		GXmlGomElement* _tmp106_ = NULL;
		GXmlGomElement* _tmp107_ = NULL;
		GXmlDomNamedNodeMap* _tmp108_ = NULL;
		GXmlDomNamedNodeMap* _tmp109_ = NULL;
		GXmlDomNamedNodeMap* _tmp110_ = NULL;
		gint _tmp111_ = 0;
		gint _tmp112_ = 0;
		GXmlGomElement* _tmp113_ = NULL;
		GXmlGomElement* _tmp114_ = NULL;
		GXmlDomNamedNodeMap* _tmp115_ = NULL;
		GXmlDomNamedNodeMap* _tmp116_ = NULL;
		GXmlDomNamedNodeMap* _tmp117_ = NULL;
		gint _tmp118_ = 0;
		gint _tmp119_ = 0;
		GXmlGomElement* _tmp120_ = NULL;
		gchar* _tmp121_ = NULL;
		gchar* _tmp122_ = NULL;
		GXmlGomElement* _tmp123_ = NULL;
		GXmlGomElement* _tmp124_ = NULL;
		gchar* _tmp125_ = NULL;
		gchar* _tmp126_ = NULL;
		GXmlGomElement* _tmp127_ = NULL;
		gchar* _tmp128_ = NULL;
		gchar* _tmp129_ = NULL;
		GXmlGomElement* _tmp130_ = NULL;
		GXmlDomNamedNodeMap* _tmp131_ = NULL;
		GXmlDomNamedNodeMap* _tmp132_ = NULL;
		GXmlDomNamedNodeMap* _tmp133_ = NULL;
		gint _tmp134_ = 0;
		gint _tmp135_ = 0;
		GXmlGomElement* _tmp140_ = NULL;
		GXmlGomElement* _tmp141_ = NULL;
		GXmlDomNamedNodeMap* _tmp142_ = NULL;
		GXmlDomNamedNodeMap* _tmp143_ = NULL;
		GXmlDomNamedNodeMap* _tmp144_ = NULL;
		GXmlGomElement* _tmp145_ = NULL;
		GXmlDomNamedNodeMap* _tmp146_ = NULL;
		GXmlDomNamedNodeMap* _tmp147_ = NULL;
		GXmlDomNamedNodeMap* _tmp148_ = NULL;
		gint _tmp149_ = 0;
		gint _tmp150_ = 0;
#line 95 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<root />", &_inner_error_);
#line 95 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 95 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 818 "GomElementTest.c"
			goto __catch227_g_error;
		}
#line 96 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = doc;
#line 96 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp1_);
#line 96 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 96 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = _tmp3_;
#line 96 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp4_ != NULL, "doc.document_element != null");
#line 96 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp4_);
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = doc;
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp6_, "alphanumeric", &_inner_error_);
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp7_;
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 843 "GomElementTest.c"
			goto __catch227_g_error;
		}
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp5_;
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = NULL;
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		elem = G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement);
#line 98 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = doc;
#line 98 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp9_);
#line 98 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 98 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 98 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp12_);
#line 98 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 98 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = _tmp14_;
#line 98 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = elem;
#line 98 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp15_, (GXmlDomNode*) _tmp16_);
#line 98 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 98 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = elem;
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp17_);
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = _tmp18_;
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp20_ != NULL, "elem.attributes != null");
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp20_);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = elem;
#line 100 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp21_);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = _tmp22_;
#line 100 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = _tmp23_;
#line 100 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = gee_map_get_size ((GeeMap*) _tmp24_);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 100 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp26_ == 0, "elem.attributes.size == 0");
#line 100 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp24_);
#line 101 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = elem;
#line 101 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp27_, "alley", "Diagon", &_inner_error_);
#line 101 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 101 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 101 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 101 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 914 "GomElementTest.c"
			goto __catch227_g_error;
		}
#line 102 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = elem;
#line 102 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp28_, "train", "Hogwarts Express", &_inner_error_);
#line 102 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 102 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 102 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 102 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 929 "GomElementTest.c"
			goto __catch227_g_error;
		}
#line 103 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = elem;
#line 103 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp29_);
#line 103 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = _tmp30_;
#line 103 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = _tmp31_;
#line 103 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = gee_map_get_size ((GeeMap*) _tmp32_);
#line 103 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 103 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp34_ == 2, "elem.attributes.size == 2");
#line 103 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp32_);
#line 104 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = doc;
#line 104 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = gxml_xparser_new ((GXmlDomNode*) _tmp35_);
#line 104 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		parser = _tmp36_;
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = parser;
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = gxml_parser_write_string ((GXmlParser*) _tmp38_, &_inner_error_);
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = _tmp39_;
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 970 "GomElementTest.c"
			goto __catch227_g_error;
		}
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = _tmp37_;
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = NULL;
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = _tmp40_;
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = g_strconcat ("Getting attributes value alley... Node: ", _tmp41_, NULL);
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = _tmp42_;
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_test_message ("%s", _tmp43_);
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp43_);
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp41_);
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = elem;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp44_);
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = _tmp45_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = gxml_dom_named_node_map_get_named_item (_tmp47_, "alley");
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = _tmp48_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = gxml_dom_node_get_node_value (_tmp49_);
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = _tmp50_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp52_ = _tmp51_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp52_, "Diagon") == 0, "elem.attributes.get_named_item (\"alley\").node_value == \"Diagon\"");
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp52_);
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp49_);
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp47_);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp53_ = elem;
#line 107 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp54_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp53_);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp55_ = _tmp54_;
#line 107 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp56_ = _tmp55_;
#line 107 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp57_ = gxml_dom_named_node_map_get_named_item (_tmp56_, "train");
#line 107 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp58_ = _tmp57_;
#line 107 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp59_ = gxml_dom_node_get_node_value (_tmp58_);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp60_ = _tmp59_;
#line 107 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp61_ = _tmp60_;
#line 107 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp61_, "Hogwarts Express") == 0, "elem.attributes.get_named_item (\"train\").node_value == \"Hogwarts Express\"");
#line 107 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp61_);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp58_);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp56_);
#line 109 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp62_ = elem;
#line 109 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp62_, "owl", "Hedwig", &_inner_error_);
#line 109 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 109 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 109 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 109 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 109 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 109 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 1057 "GomElementTest.c"
			goto __catch227_g_error;
		}
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp63_ = elem;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp64_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp63_);
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp65_ = _tmp64_;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp66_ = _tmp65_;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp67_ = gxml_dom_named_node_map_get_named_item (_tmp66_, "owl");
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp68_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp67_, GXML_TYPE_GOM_ATTR) ? ((GXmlGomAttr*) _tmp67_) : NULL;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (_tmp68_ == NULL) {
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp67_);
#line 1076 "GomElementTest.c"
		}
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp69_ = _tmp68_;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp66_);
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		attr = _tmp69_;
#line 111 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp70_ = attr;
#line 111 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp70_ != NULL, "attr != null");
#line 112 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp71_ = attr;
#line 112 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp72_ = gxml_dom_node_get_node_value ((GXmlDomNode*) _tmp71_);
#line 112 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp73_ = _tmp72_;
#line 112 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp74_ = _tmp73_;
#line 112 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp74_, "Hedwig") == 0, "attr.node_value == \"Hedwig\"");
#line 112 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp74_);
#line 114 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp75_ = elem;
#line 114 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp76_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp75_);
#line 114 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp77_ = _tmp76_;
#line 114 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp78_ = _tmp77_;
#line 114 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp79_ = gee_map_get_size ((GeeMap*) _tmp78_);
#line 114 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp80_ = _tmp79_;
#line 114 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp80_ == 3, "elem.attributes.size == 3");
#line 114 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp78_);
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp81_ = elem;
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp82_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp81_, "owl");
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp83_ = _tmp82_;
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp83_, "Hedwig") == 0, "elem.get_attribute (\"owl\") == \"Hedwig\"");
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp83_);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp84_ = elem;
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp85_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp84_);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp86_ = _tmp85_;
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp87_ = _tmp86_;
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp88_ = gxml_dom_named_node_map_remove_named_item (_tmp87_, "alley", &_inner_error_);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp89_ = _tmp88_;
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp89_);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp87_);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 1156 "GomElementTest.c"
			goto __catch227_g_error;
		}
#line 119 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp90_ = elem;
#line 119 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp91_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp90_, "alley");
#line 119 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp92_ = _tmp91_;
#line 119 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp92_ == NULL, "elem.get_attribute (\"alley\") == null");
#line 119 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp92_);
#line 120 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp93_ = elem;
#line 120 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp94_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp93_);
#line 120 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp95_ = _tmp94_;
#line 120 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp96_ = _tmp95_;
#line 120 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp97_ = gee_map_get_size ((GeeMap*) _tmp96_);
#line 120 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp98_ = _tmp97_;
#line 120 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp98_ == 2, "elem.attributes.size == 2");
#line 120 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp96_);
#line 121 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp99_ = elem;
#line 121 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_remove_attribute ((GXmlDomElement*) _tmp99_, "owl");
#line 122 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp100_ = elem;
#line 122 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp101_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp100_);
#line 122 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp102_ = _tmp101_;
#line 122 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp103_ = _tmp102_;
#line 122 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp104_ = gee_map_get_size ((GeeMap*) _tmp103_);
#line 122 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp105_ = _tmp104_;
#line 122 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp105_ == 1, "elem.attributes.size == 1");
#line 122 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp103_);
#line 124 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp106_ = elem;
#line 124 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp106_, "http://www.w3.org/2000/xmlns/", "xmlns:gxml", "http://www.gnome.org/GXml", &_inner_error_);
#line 124 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 124 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 124 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 124 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 124 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 124 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 124 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 1223 "GomElementTest.c"
			goto __catch227_g_error;
		}
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp107_ = elem;
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp108_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp107_);
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp109_ = _tmp108_;
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp110_ = _tmp109_;
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp111_ = gee_map_get_size ((GeeMap*) _tmp110_);
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp112_ = _tmp111_;
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp112_ == 2, "elem.attributes.size == 2");
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp110_);
#line 127 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp113_ = elem;
#line 127 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp113_, "http://www.gnome.org/GXml", "gxml:xola", "Mexico", &_inner_error_);
#line 127 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 127 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 127 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 127 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 127 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 127 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 127 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 1260 "GomElementTest.c"
			goto __catch227_g_error;
		}
#line 128 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp114_ = elem;
#line 128 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp115_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp114_);
#line 128 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp116_ = _tmp115_;
#line 128 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp117_ = _tmp116_;
#line 128 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp118_ = gee_map_get_size ((GeeMap*) _tmp117_);
#line 128 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp119_ = _tmp118_;
#line 128 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp119_ == 3, "elem.attributes.size == 3");
#line 128 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp117_);
#line 129 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp120_ = elem;
#line 129 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp121_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp120_, "http://www.gnome.org/GXml", "xola");
#line 129 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp122_ = _tmp121_;
#line 129 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp122_, "Mexico") == 0, "elem.get_attribute_ns (\"http://www.gnome.org/GXml\", \"xola\") == \"Mexico\"");
#line 129 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp122_);
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp123_ = elem;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_remove_attribute_ns ((GXmlDomElement*) _tmp123_, "http://www.gnome.org/GXml", "xola");
#line 131 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp124_ = elem;
#line 131 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp125_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp124_, "http://www.gnome.org/GXml", "xola");
#line 131 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp126_ = _tmp125_;
#line 131 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp126_ == NULL, "elem.get_attribute_ns (\"http://www.gnome.org/GXml\", \"xola\") == null");
#line 131 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp126_);
#line 132 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp127_ = elem;
#line 132 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp128_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp127_, "xola");
#line 132 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp129_ = _tmp128_;
#line 132 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp129_ == NULL, "elem.get_attribute (\"xola\") == null");
#line 132 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp129_);
#line 133 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp130_ = elem;
#line 133 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp131_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp130_);
#line 133 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp132_ = _tmp131_;
#line 133 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp133_ = _tmp132_;
#line 133 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp134_ = gee_map_get_size ((GeeMap*) _tmp133_);
#line 133 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp135_ = _tmp134_;
#line 133 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp135_ == 2, "elem.attributes.size == 2");
#line 133 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp133_);
#line 1329 "GomElementTest.c"
		{
			GXmlGomElement* _tmp136_ = NULL;
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp136_ = elem;
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp136_, "http://www.gnome.org/GXml", "gxml2:xola", "Mexico", &_inner_error_);
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1338 "GomElementTest.c"
				goto __catch228_g_error;
			}
#line 139 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			g_assert_not_reached ();
#line 1343 "GomElementTest.c"
		}
		goto __finally228;
		__catch228_g_error:
		{
			GError* e = NULL;
			const gchar* _tmp137_ = NULL;
			gchar* _tmp138_ = NULL;
			gchar* _tmp139_ = NULL;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			e = _inner_error_;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_inner_error_ = NULL;
#line 141 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp137_ = e->message;
#line 141 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp138_ = g_strconcat ("Correctly Cough Error:", _tmp137_, NULL);
#line 141 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp139_ = _tmp138_;
#line 141 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			g_message ("GomElementTest.vala:141: %s", _tmp139_);
#line 141 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp139_);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_error_free0 (e);
#line 1368 "GomElementTest.c"
		}
		__finally228:
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 1385 "GomElementTest.c"
			goto __catch227_g_error;
		}
#line 143 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp140_ = elem;
#line 143 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp140_ != NULL, "elem != null");
#line 144 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp141_ = elem;
#line 144 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp142_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp141_);
#line 144 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp143_ = _tmp142_;
#line 144 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp144_ = _tmp143_;
#line 144 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp144_ != NULL, "elem.attributes != null");
#line 144 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp144_);
#line 145 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp145_ = elem;
#line 145 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp146_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp145_);
#line 145 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp147_ = _tmp146_;
#line 145 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp148_ = _tmp147_;
#line 145 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp149_ = gee_map_get_size ((GeeMap*) _tmp148_);
#line 145 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp150_ = _tmp149_;
#line 145 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp150_ == 2, "elem.attributes.size == 2");
#line 145 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp148_);
#line 94 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (attr);
#line 94 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp37_);
#line 94 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (parser);
#line 94 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (elem);
#line 94 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp5_);
#line 94 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 1432 "GomElementTest.c"
	}
	goto __finally227;
	__catch227_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp151_ = NULL;
#line 94 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 94 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp151_ = e->message;
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:147: %s", _tmp151_);
#line 148 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 94 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 1451 "GomElementTest.c"
	}
	__finally227:
#line 94 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 94 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 94 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 94 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 1462 "GomElementTest.c"
	}
}


static void ___lambda237__gtest_func (void) {
#line 93 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda237_ ();
#line 1470 "GomElementTest.c"
}


static void __lambda238_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlGomElement* root = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlGomDocument* _tmp5_ = NULL;
		GXmlDomNodeList* _tmp6_ = NULL;
		GXmlDomNodeList* _tmp7_ = NULL;
		GXmlDomNodeList* _tmp8_ = NULL;
		GXmlGomElement* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlGomDocument* _tmp11_ = NULL;
		GXmlDomElement* _tmp12_ = NULL;
		GXmlGomElement* n = NULL;
		GXmlDomElement* _tmp13_ = NULL;
		GXmlGomElement* _tmp14_ = NULL;
		GXmlDomNodeList* _tmp15_ = NULL;
		GXmlDomNodeList* _tmp16_ = NULL;
		GXmlDomNodeList* _tmp17_ = NULL;
		GXmlGomElement* _tmp18_ = NULL;
		GXmlDomText* t = NULL;
		GXmlGomDocument* _tmp19_ = NULL;
		GXmlDomText* _tmp20_ = NULL;
		GXmlGomElement* _tmp21_ = NULL;
		GXmlDomNodeList* _tmp22_ = NULL;
		GXmlDomNodeList* _tmp23_ = NULL;
		GXmlDomNodeList* _tmp24_ = NULL;
		GXmlDomText* _tmp25_ = NULL;
		GXmlXParser* parser = NULL;
		GXmlGomDocument* _tmp26_ = NULL;
		GXmlXParser* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		GXmlXParser* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* s = NULL;
		gchar* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		gchar** _tmp33_ = NULL;
		gchar** _tmp34_ = NULL;
		gchar** _tmp35_ = NULL;
		gint _tmp35__length1 = 0;
		const gchar* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
#line 153 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 153 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 154 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = doc;
#line 154 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp2_, "root", &_inner_error_);
#line 154 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = _tmp3_;
#line 154 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 154 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 1537 "GomElementTest.c"
			goto __catch229_g_error;
		}
#line 154 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = _tmp1_;
#line 154 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = NULL;
#line 154 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement);
#line 155 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = doc;
#line 155 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp5_);
#line 155 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 155 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 155 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = root;
#line 155 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp8_, (GXmlDomNode*) _tmp9_);
#line 155 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = doc;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp11_, "child", &_inner_error_);
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp12_;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 1574 "GomElementTest.c"
			goto __catch229_g_error;
		}
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = _tmp10_;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = NULL;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n = G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement);
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = root;
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp14_);
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = _tmp15_;
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = n;
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp17_, (GXmlDomNode*) _tmp18_);
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp17_);
#line 158 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = doc;
#line 158 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = gxml_dom_document_create_text_node ((GXmlDomDocument*) _tmp19_, "TEXT1", &_inner_error_);
#line 158 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		t = _tmp20_;
#line 158 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 158 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 158 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp10_);
#line 158 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 158 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 158 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 1615 "GomElementTest.c"
			goto __catch229_g_error;
		}
#line 159 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = root;
#line 159 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp21_);
#line 159 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = _tmp22_;
#line 159 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = _tmp23_;
#line 159 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = t;
#line 159 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp24_, (GXmlDomNode*) _tmp25_);
#line 159 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp24_);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = doc;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = gxml_xparser_new ((GXmlDomNode*) _tmp26_);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		parser = _tmp27_;
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = parser;
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = gxml_parser_write_string ((GXmlParser*) _tmp29_, &_inner_error_);
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = _tmp30_;
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (t);
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp10_);
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 1660 "GomElementTest.c"
			goto __catch229_g_error;
		}
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = _tmp28_;
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = NULL;
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = _tmp31_;
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_ = g_strsplit (_tmp32_, "\n", 0);
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = _tmp34_;
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35__length1 = _vala_array_length (_tmp33_);
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = _tmp35_[1];
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = g_strdup (_tmp36_);
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = _tmp37_;
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = (_vala_array_free (_tmp35_, _tmp35__length1, (GDestroyNotify) g_free), NULL);
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp32_);
#line 161 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		s = _tmp38_;
#line 162 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (s, "<root><child/>TEXT1</root>") == 0, "s == \"<root><child/>TEXT1</root>\"");
#line 152 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (s);
#line 152 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp28_);
#line 152 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (parser);
#line 152 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (t);
#line 152 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n);
#line 152 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp10_);
#line 152 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (root);
#line 152 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp1_);
#line 152 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 1707 "GomElementTest.c"
	}
	goto __finally229;
	__catch229_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp39_ = NULL;
#line 152 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 152 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 164 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = e->message;
#line 164 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_test_message ("%s", _tmp39_);
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 152 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 1726 "GomElementTest.c"
	}
	__finally229:
#line 152 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 152 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 152 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 152 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 1737 "GomElementTest.c"
	}
}


static void ___lambda238__gtest_func (void) {
#line 151 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda238_ ();
#line 1745 "GomElementTest.c"
}


static void __lambda239_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlGomElement* root = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlGomDocument* _tmp5_ = NULL;
		GXmlDomNodeList* _tmp6_ = NULL;
		GXmlDomNodeList* _tmp7_ = NULL;
		GXmlDomNodeList* _tmp8_ = NULL;
		GXmlGomElement* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlGomDocument* _tmp11_ = NULL;
		GXmlDomElement* _tmp12_ = NULL;
		GXmlGomElement* n = NULL;
		GXmlDomElement* _tmp13_ = NULL;
		GXmlGomElement* _tmp14_ = NULL;
		GXmlDomNodeList* _tmp15_ = NULL;
		GXmlDomNodeList* _tmp16_ = NULL;
		GXmlDomNodeList* _tmp17_ = NULL;
		GXmlGomElement* _tmp18_ = NULL;
		GXmlDomText* _tmp19_ = NULL;
		GXmlGomDocument* _tmp20_ = NULL;
		GXmlDomText* _tmp21_ = NULL;
		GXmlDomText* t = NULL;
		GXmlDomText* _tmp22_ = NULL;
		GXmlDomText* _tmp23_ = NULL;
		GXmlGomElement* _tmp24_ = NULL;
		GXmlDomNodeList* _tmp25_ = NULL;
		GXmlDomNodeList* _tmp26_ = NULL;
		GXmlDomNodeList* _tmp27_ = NULL;
		GXmlDomText* _tmp28_ = NULL;
		GXmlXParser* parser = NULL;
		GXmlGomDocument* _tmp29_ = NULL;
		GXmlXParser* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		GXmlXParser* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		gchar* s = NULL;
		gchar* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		gchar** _tmp36_ = NULL;
		gchar** _tmp37_ = NULL;
		gchar** _tmp38_ = NULL;
		gint _tmp38__length1 = 0;
		const gchar* _tmp39_ = NULL;
		gchar* _tmp40_ = NULL;
		gchar* _tmp41_ = NULL;
#line 170 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 170 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 171 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = doc;
#line 171 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp2_, "root", &_inner_error_);
#line 171 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = _tmp3_;
#line 171 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 171 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 1815 "GomElementTest.c"
			goto __catch230_g_error;
		}
#line 171 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = _tmp1_;
#line 171 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = NULL;
#line 171 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement);
#line 172 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = doc;
#line 172 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp5_);
#line 172 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 172 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 172 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = root;
#line 172 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp8_, (GXmlDomNode*) _tmp9_);
#line 172 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = doc;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp11_, "child", &_inner_error_);
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp12_;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 1852 "GomElementTest.c"
			goto __catch230_g_error;
		}
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = _tmp10_;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = NULL;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n = G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement);
#line 174 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = root;
#line 174 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp14_);
#line 174 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = _tmp15_;
#line 174 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 174 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = n;
#line 174 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp17_, (GXmlDomNode*) _tmp18_);
#line 174 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp17_);
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = doc;
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = gxml_dom_document_create_text_node ((GXmlDomDocument*) _tmp20_, "TEXT1", &_inner_error_);
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = _tmp21_;
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp10_);
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 1893 "GomElementTest.c"
			goto __catch230_g_error;
		}
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = _tmp19_;
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = NULL;
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, GXML_TYPE_DOM_TEXT) ? ((GXmlDomText*) _tmp22_) : NULL;
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (_tmp23_ == NULL) {
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp22_);
#line 1906 "GomElementTest.c"
		}
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		t = _tmp23_;
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = root;
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp24_);
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = _tmp26_;
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = t;
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp27_, (GXmlDomNode*) _tmp28_);
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp27_);
#line 177 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = doc;
#line 177 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = gxml_xparser_new ((GXmlDomNode*) _tmp29_);
#line 177 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		parser = _tmp30_;
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = parser;
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = gxml_parser_write_string ((GXmlParser*) _tmp32_, &_inner_error_);
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = _tmp33_;
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (t);
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp19_);
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp10_);
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 1954 "GomElementTest.c"
			goto __catch230_g_error;
		}
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp31_;
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = NULL;
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = _tmp34_;
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = _tmp36_ = g_strsplit (_tmp35_, "\n", 0);
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = _tmp37_;
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38__length1 = _vala_array_length (_tmp36_);
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = _tmp38_[1];
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = g_strdup (_tmp39_);
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = _tmp40_;
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = (_vala_array_free (_tmp38_, _tmp38__length1, (GDestroyNotify) g_free), NULL);
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp35_);
#line 178 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		s = _tmp41_;
#line 179 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (s, "<root><child/>TEXT1</root>") == 0, "s == \"<root><child/>TEXT1</root>\"");
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (s);
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp31_);
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (parser);
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (t);
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp19_);
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n);
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp10_);
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (root);
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp1_);
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 2003 "GomElementTest.c"
	}
	goto __finally230;
	__catch230_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp42_ = NULL;
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 181 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = e->message;
#line 181 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_test_message ("%s", _tmp42_);
#line 182 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 2022 "GomElementTest.c"
	}
	__finally230:
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 2033 "GomElementTest.c"
	}
}


static void ___lambda239__gtest_func (void) {
#line 168 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda239_ ();
#line 2041 "GomElementTest.c"
}


static void __lambda240_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlDomElement* _tmp5_ = NULL;
		GXmlDomElement* _tmp6_ = NULL;
		GXmlDomNode* _tmp7_ = NULL;
		GXmlDomNode* _tmp8_ = NULL;
		GXmlDomNode* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlDomElement* _tmp11_ = NULL;
		GXmlDomElement* _tmp12_ = NULL;
		GXmlDomNode* _tmp13_ = NULL;
		GXmlDomNode* _tmp14_ = NULL;
		GXmlDomNode* _tmp15_ = NULL;
		GXmlDomElement* _tmp16_ = NULL;
		GXmlDomElement* _tmp17_ = NULL;
		GXmlDomElement* _tmp18_ = NULL;
		GXmlDomNodeList* _tmp19_ = NULL;
		GXmlDomNodeList* _tmp20_ = NULL;
		GXmlDomNodeList* _tmp21_ = NULL;
		gpointer _tmp22_ = NULL;
		GXmlDomNode* _tmp23_ = NULL;
		GXmlDomElement* _tmp24_ = NULL;
		GXmlDomElement* _tmp25_ = NULL;
		GXmlDomElement* _tmp26_ = NULL;
		GXmlDomNodeList* _tmp27_ = NULL;
		GXmlDomNodeList* _tmp28_ = NULL;
		GXmlDomNodeList* _tmp29_ = NULL;
		gpointer _tmp30_ = NULL;
		GXmlDomNode* _tmp31_ = NULL;
		GXmlDomNode* _tmp32_ = NULL;
		GXmlDomNode* _tmp33_ = NULL;
		GXmlDomNode* _tmp34_ = NULL;
		GXmlDomElement* _tmp35_ = NULL;
		GXmlDomElement* _tmp36_ = NULL;
		GXmlDomElement* _tmp37_ = NULL;
		GXmlDomNodeList* _tmp38_ = NULL;
		GXmlDomNodeList* _tmp39_ = NULL;
		GXmlDomNodeList* _tmp40_ = NULL;
		gpointer _tmp41_ = NULL;
		GXmlDomNode* _tmp42_ = NULL;
		GXmlDomNode* _tmp43_ = NULL;
		GXmlDomNode* _tmp44_ = NULL;
		GXmlDomNode* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
#line 187 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<root><child/></root>", &_inner_error_);
#line 187 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 187 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2104 "GomElementTest.c"
			goto __catch231_g_error;
		}
#line 188 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 188 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = _tmp1_;
#line 188 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 188 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp3_ != NULL, "doc.document_element != null");
#line 188 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp3_);
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = _tmp5_;
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp6_);
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_DOM_NODE), "doc.document_element.parent_node is GXml.DomNode");
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp9_);
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp6_);
#line 190 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 190 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp12_);
#line 190 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = _tmp14_;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOM_DOCUMENT), "doc.document_element.parent_node is GXml.DomDocument");
#line 190 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 190 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 191 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 191 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 191 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = _tmp17_;
#line 191 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp18_);
#line 191 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 191 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = _tmp20_;
#line 191 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = gee_list_get ((GeeList*) _tmp21_, 0);
#line 191 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = (GXmlDomNode*) _tmp22_;
#line 191 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp23_ != NULL, "doc.document_element.child_nodes[0] != null");
#line 191 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp23_);
#line 191 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp21_);
#line 191 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp18_);
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp26_);
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = _tmp27_;
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = _tmp28_;
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = gee_list_get ((GeeList*) _tmp29_, 0);
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = (GXmlDomNode*) _tmp30_;
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = gxml_dom_node_get_parent_node (_tmp31_);
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp34_ != NULL, "doc.document_element.child_nodes[0].parent_node != null");
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp34_);
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp31_);
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp29_);
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = _tmp35_;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp37_);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = _tmp39_;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = gee_list_get ((GeeList*) _tmp40_, 0);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = (GXmlDomNode*) _tmp41_;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = gxml_dom_node_get_parent_node (_tmp42_);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = _tmp43_;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = gxml_dom_node_get_node_name (_tmp45_);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = _tmp47_;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp48_, "root") == 0, "doc.document_element.child_nodes[0].parent_node.node_name == \"root\"");
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp48_);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp45_);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp42_);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp37_);
#line 186 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 2251 "GomElementTest.c"
	}
	goto __finally231;
	__catch231_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
#line 186 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 186 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 195 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = e->message;
#line 195 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = g_strconcat ("Error: ", _tmp49_, NULL);
#line 195 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = _tmp50_;
#line 195 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:195: %s", _tmp51_);
#line 195 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp51_);
#line 196 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 186 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 2278 "GomElementTest.c"
	}
	__finally231:
#line 186 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 186 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 186 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 186 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 2289 "GomElementTest.c"
	}
}


static void ___lambda240__gtest_func (void) {
#line 185 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda240_ ();
#line 2297 "GomElementTest.c"
}


void gom_element_test_add_tests (void) {
#line 27 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/read/namespace_uri", ___lambda235__gtest_func);
#line 59 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/namespace_uri", ___lambda236__gtest_func);
#line 93 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/attributes", ___lambda237__gtest_func);
#line 151 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/content/add_aside_child_nodes", ___lambda238__gtest_func);
#line 168 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/content/keep_child_nodes", ___lambda239__gtest_func);
#line 185 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/parent", ___lambda240__gtest_func);
#line 2314 "GomElementTest.c"
}


GomElementTest* gom_element_test_construct (GType object_type) {
	GomElementTest* self = NULL;
#line 25 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTest*) gxml_test_construct (object_type);
#line 25 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 2324 "GomElementTest.c"
}


GomElementTest* gom_element_test_new (void) {
#line 25 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_construct (TYPE_GOM_ELEMENT_TEST);
#line 2331 "GomElementTest.c"
}


static void gom_element_test_class_init (GomElementTestClass * klass) {
#line 25 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_parent_class = g_type_class_peek_parent (klass);
#line 2338 "GomElementTest.c"
}


static void gom_element_test_instance_init (GomElementTest * self) {
}


GType gom_element_test_get_type (void) {
	static volatile gsize gom_element_test_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTest), 0, (GInstanceInitFunc) gom_element_test_instance_init, NULL };
		GType gom_element_test_type_id;
		gom_element_test_type_id = g_type_register_static (TYPE_GXML_TEST, "GomElementTest", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_type_id__volatile, gom_element_test_type_id);
	}
	return gom_element_test_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



